@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mwim" "0.4"
+(define-package "mwim" "20260227.705"
   "Switch between the beginning/end of line or code."
-  ()
+  '((seq "2.24"))
   :url "https://github.com/alezost/mwim.el"
-  :commit "462207227b98a6a4356d51419f5ad5ba9356e5cf"
-  :revdesc "462207227b98"
+  :commit "e44a7a0a76262d7000b726bfa848cc62e21d7985"
+  :revdesc "e44a7a0a7626"
   :keywords '("convenience")
   :authors '(("Alex Kost" . "alezost@gmail.com"))
   :maintainers '(("Alex Kost" . "alezost@gmail.com")))
